## Version 0.2.0 (2022-04-05)
### 🎉 New features

- cube-doctor: add add-set-cubicweb-max-version
- setup.py: increase cubicweb max version to 3.31.x
- setup.py: increase cubicweb max version to 3.32.x
- setup.py: increase cubicweb max version to 3.33.x
- setup.py: increase cubicweb max version to 3.33.x
- setup.py: increase cubicweb max version to 3.33.x
- setup.py: increase cubicweb max version to 3.34.x
- setup.py: increase cubicweb max version to 3.34.x
- setup.py: increase cubicweb max version to 3.34.x
- setup.py: increase cubicweb max version to 3.35.x

### 📝 Documentation

- licence: update licence dates

## Version 0.1.5 (2021-08-25)
### 👷 Bug fixes

- views.py

## Version 0.1.4 (2021-05-12)
### 👷 Bug fixes

- setup.py

## Version 0.1.3 (2021-05-12)
### 👷 Bug fixes

- packaging: depend on cubicweb 3.27

## Version 0.1.2 (2021-05-11)

- packaging

## Version 0.1.1 (2021-05-11)
### 🤷 Various changes

- First working version